@@ -50,6 +50,14 @@ DWMWA_USE_IMMERSIVE_DARK_MODE = 20
 
 
 def AddShortCut(File, Link="link.lnk", Path: str = ".//"):
+
+    """
+    给文件添加一个快捷键到指定位置
+
+    File指定文件，Link指定快捷键名称，Path指定保存的位置。
+
+    """
+
     from win32com.client import Dispatch
     from shutil import move
     Shell = Dispatch("WScript.Shell")
@@ -130,6 +138,7 @@ def Install(Library, Basic: bool = True, Preview: bool = False, Pypi="https://py
 
 
 def Install_ALL(Basic=True, Preview: bool = False, Pypi="https://pypi.tuna.tsinghua.edu.cn/simple/"):
+    import sys
     Install("tkinter-tooltip", Basic=Basic, Pypi=Pypi, Preview=Preview)
     Install("pywin32", Basic=Basic, Pypi=Pypi, Preview=Preview)
     if sys.platform == "win32" and sys.getwindowsversion().build >= 22000:
@@ -1040,6 +1049,12 @@ class DevTooltip(DevToplevel):
     def __init__(self, widget: tk.Widget, window: tk.Tk, message: str = "", after: int = 1000, border: bool = True,
                  padding: int = 3, side=tk.CENTER, height: int = 40,
                  background="#ffffff", foreground="#000000"):
+
+        """
+        用于给组件设定工具提示
+
+        widget表示设置工具提示的组件，window表示设置组件的窗口，message表示工具提示的文本，after表示几秒之后显示，border是否设定为窗口的边框。
+        """
         super(DevTooltip, self).__init__()
         self.configure(background=background, relief=tk.RAISED, border=1)
         from tkdev import window_border
@@ -1106,4 +1121,4 @@ class DevTooltip(DevToplevel):
 
 
 if __name__ == '__main__':
-    Package("C:\\tkinterDev\\demo-4.py", Ofter="-F -w")
+    Install_ALL()
